// project:		Transitions to parenthood, flexible working and time-based work-to-family conflicts
// updated: 	2022-02-22


*****************************************************************************************************************
*****************************************************************************************************************
************                                                                                         ************
************                                                                                         ************
************ // 0.                                                                                   ************
************ // Set Macros                                                                           ************
************                                                                                         ************
************                                                                                         ************
*****************************************************************************************************************
*****************************************************************************************************************

clear all
version 14.0
capture log close
set more off

// Globals definieren

global date "2022-02-22"
global data "#"
global do "#"
global results "#"
global log "#"


log using "X\WFC.log", replace

*****************************************************************************************************************
*****************************************************************************************************************
************                                                                                         ************
************                                                                                         ************
************ // 1.                                                                                   ************
************ // Definition of sample                                                                 ************
************                                                                                         ************
************                                                                                         ************
*****************************************************************************************************************
*****************************************************************************************************************

*Open generated data (long format)
use "$data\WFC_long", clear

*Set xt format
xtset paarnr year
xtdescribe

********************************************
***                                      ***
***  // 1.1                              ***
***  // Defining sample for              ***
***     longitudinal analyses            ***
***                                      ***
********************************************

**Select partnered respondents


gen newsample=.
replace newsample=1 if partner==1
replace newsample=0 if partner==0

xttab newsample //Overall 11989


********************************************
***                                      ***
***  // 1.2                              ***
***  // Sample reduction due to          ***
***     missing values                   ***
***                                      ***
********************************************

// Cases with missings on dependent variable

 xtreg IndexWFCt if newsample==1, fe i(paarnr) vce(robust)
 gen newsample2 = e(sample) 
   
xttab newsample2 //11951

// Estimation of full model without missings on independent variables

 xtreg IndexWFCt child alter_j_kind i.jaheiman i.jaflexazn i.year  jazouh  isei08a exper_yr tenure_yr uebstun O_flex O_heim if newsample2==1 , fe i(paarnr) vce(robust)
 
  gen newsample3 = e(sample)  
  
  xttab newsample3 //11821


//No missing on occupation, sector, hourly pay for sensitivity analyses

 xtreg IndexWFCt child alter_j_kind i.jaheiman i.jaflexazn  i.year  jazouh  isei08a st_lohn exper_yr tenure_yr uebstun O_flex O_heim i.WZN i.isco08_1sta  if newsample3==1 , fe i(paarnr) vce(robust)


  gen newsample4 = e(sample)  
  
  xttab newsample4 //11303

  keep if newsample4==1
  
  //Minimum of 2 observations

bysort paarnr: gen N = _N 
tab N , mis 

keep if N== 2  | N==3

tab N, mis //8588

tab sexid, mis // 3793 observations for women and 4795 observations for men

save "X\WFC_long_selsample.dta", replace

*****************************************************************************************************************
*****************************************************************************************************************
************                                                                                         ************
************                                                                                         ************
************ // 2.                                                                                   ************
************ // Descriptive Analyses                                                                 ************
************                                                                                         ************
************                                                                                         ************
*****************************************************************************************************************
*****************************************************************************************************************

*******************Descriptives************************

*Women 

*Transitions 
xttrans child if sexid==0, fre
xttrans jaheiman if sexid==0, fre
xttrans jaflexazn  if sexid==0, fre

*Descriptive dummy variables 
xttab  child if sexid==0
xttab jaheiman  if sexid==0
xttab  jaflexazn  if sexid==0


**Descriptive continuous variables 
xtsum O_heim O_flex  jazouh uebstun isei08a exper_yr tenure_yr alter_j_kind IndexWFCt if sexid==0

*Men

*Transitions
xttrans child if sexid==1, fre
xttrans jaheiman if sexid==1, fre
xttrans jaflexazn  if sexid==1, fre

*Descriptive dummy variables 
xttab  child if sexid==1
xttab jaheiman  if sexid==1
xttab  jaflexazn  if sexid==1

**Descriptive continuous variables 
xtsum O_heim O_flex  jazouh uebstun  isei08a  exper_yr tenure_yr alter_j_kind IndexWFCt if sexid==1




*****************************************************************************************************************
*****************************************************************************************************************
************                                                                                         ************
************                                                                                         ************
************ // 4.                                                                                   ************
************ // Multivariate Analyses                                                                ************
************                                                                                         ************
************                                                                                         ************
*****************************************************************************************************************
*****************************************************************************************************************


********************************************
***                                      ***
***  // Table 1                          ***
***                                      ***
***                                      ***
********************************************

// Fixed-Effects Linear Regression models
// DV=IndexWFCt; main IV=child

xtset paarnr year 

*Women M1
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0, fe i(paarnr) vce(robust)
est store M1F
*Men M1
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1, fe i(paarnr) vce(robust) 
est store M1M
**Women M2
xtreg  IndexWFCt child  jazouh  uebstun  exper_yr tenure_yr isei08a alter_j_kind  i.year if sexid==0, fe i(paarnr) vce(robust)
est store M2F
*Men M2
xtreg  IndexWFCt child jazouh uebstun  exper_yr tenure_yr isei08a  alter_j_kind  i.year if sexid==1, fe i(paarnr) vce(robust)
est store M2M


esttab  M1F  M2F M1M M2M /*
*/ using "X\Results Table 1.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)




********************************************
***                                      ***
***  // Table 2                          ***
***                                      ***
***                                      ***
********************************************

// Fixed-Effects Linear Regression models
// DV=IndexWFCt; main IV=child and flexible working

*Women M1
xtreg  IndexWFCt child i.jaheiman i.jaflexazn  alter_j_kind  i.year  if sexid==0, fe i(paarnr) vce(robust)
est store M1F
* Men M1 
xtreg  IndexWFCt child i.jaheiman i.jaflexazn  alter_j_kind  i.year  if sexid==1, fe i(paarnr) vce(robust)
est store M1M
*Women M2
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0, fe i(paarnr) vce(robust) 
est store M2F
* Men M2
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==1, fe i(paarnr) vce(robust)
est store M2M
*Women M3
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child  jazouh uebstun exper_yr tenure_yr isei08a  alter_j_kind  i.year  if sexid==0, fe i(paarnr) vce(robust) 
est store M3F
* Men M3
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child  jazouh uebstun  exper_yr tenure_yr isei08a alter_j_kind  i.year  if sexid==1, fe i(paarnr) vce(robust) 
est store M3M


esttab  M1F  M2F M3F M1M M2M M3M /*
*/ using "X\Results Table 2.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

********************************************
***                                      ***
***  // Figure 1                         ***
***                                      ***
***                                      ***
********************************************

**Visualization of significant interaction effects in Table 2 M2 

*Women 
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0, fe i(paarnr) vce(robust) 
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 


xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child  jazouh uebstun exper_yr tenure_yr  isei08a alter_j_kind  i.year if sexid==0, fe i(paarnr) vce(robust) 
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 


********************************************
***                                      ***
***  // Table 3                          ***
***                                      ***
***                                      ***
********************************************
// Fixed-Effects Linear Regression models
// DV=IndexWFCt; main IV=Organizational share - use of flexible working

*Women
xtreg  IndexWFCt O_heim O_flex  if sexid==0,  fe i(paarnr) vce(robust) 
est store O1
xtreg  IndexWFCt O_heim O_flex jaheiman jaflexazn  if sexid==0,  fe i(paarnr) vce(robust) 
est store O2
xtreg  IndexWFCt O_heim  O_flex  jaheiman jaflexazn i.year  if sexid==0,  fe i(paarnr) vce(robust) 
est store O3 
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn i.year  child alter_j_kind jazouh uebst exper_yr tenure_yr isei08a  if sexid==0,  fe i(paarnr) vce(robust) 
est store O4

esttab O1 O2 O3 O4  /*
*/ using "X\Results Table 3A Women.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*Men
xtreg  IndexWFCt O_heim O_flex if sexid==1 , fe i(paarnr) vce(robust) 
est store O1m
xtreg  IndexWFCt O_heim  O_flex jaheiman jaflexazn  if sexid==1 , fe i(paarnr) vce(robust) 
est store O2m
xtreg  IndexWFCt O_heim  O_flex  jaheiman jaflexazn i.year if sexid==1 , fe i(paarnr) vce(robust) 
est store O3m
xtreg  IndexWFCt O_heim O_flex jaheiman jaflexazn  i.year child alter_j_kind jazouh uebst exper_yr tenure_yr  isei08a  if sexid==1 , fe i(paarnr) vce(robust) 
est store O4m


esttab O1m O2m O3m O4m /*
*/ using "X\Results Table 3B Men.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)



save "X\WFC_long_selsample.dta", replace

*****************************************************************************************************************
*****************************************************************************************************************
************                                                                                         ************
************                                                                                         ************
************ // 5.                                                                                   ************
************ // Sensitivity Analyses                                                                 ************
************                                                                                         ************
************                                                                                         ************
*****************************************************************************************************************
*****************************************************************************************************************



********************************************
***                                      ***
***  // hourly pay instead of isei       ***
***  // Table 1A Online Appendix A       ***
***                                      ***
********************************************


*Women M1
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0, fe i(paarnr) vce(robust)
est store M1F
*Men M1
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1, fe i(paarnr) vce(robust) 
est store M1M
**Women M2
xtreg  IndexWFCt child jazouh uebstun exper_yr tenure_yr  st_lohn alter_j_kind  i.year if sexid==0, fe i(paarnr) vce(robust)
est store M2F
*Men M2
xtreg  IndexWFCt child jazouh uebstun exper_yr tenure_yr  st_lohn alter_j_kind  i.year if sexid==1, fe i(paarnr) vce(robust)
est store M2M


esttab  M1F  M2F M1M M2M /*
*/ using "X\Results Table 1A Online Appendix A.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


********************************************
***                                      ***
***  // with information on employment   ***
***     situation partner 				 *** 	
*** // Table 1B and Figure 1B 			 *** 
***                                      ***
********************************************

//Table 1B 

 xtreg IndexWFCt child alter_j_kind i.jaheiman i.jaflexazn  i.year  jazouh uebstun  exper_yr tenure_yr  isei08a  pberwbt pbazouh , fe i(paarnr) vce(robust)

gen senssample1 = e(sample)  

xttab senssample1
bysort sexid: xttab  senssample1

keep if senssample1==1

drop N

bysort paarnr: gen N = _N if  senssample1==1
tab N , mis 

keep if N==2 | N==3
  
save "X\senssample partner employment", replace
  
* Women M1
xtreg  IndexWFCt child alter_j_kind  i.year pberwbt  pbazouh  if sexid==0, fe i(paarnr) vce(robust) 
est store M1F
*Men M1 
xtreg  IndexWFCt child alter_j_kind  i.year pberwbt  pbazouh if sexid==1, fe i(paarnr) vce(robust)
est store M1M
**Women M2
xtreg  IndexWFCt child  jazouh uebstun  exper_yr tenure_yr   isei08a alter_j_kind  i.year pberwbt  pbazouh if sexid==0, fe i(paarnr) vce(robust)
est store M2F
*Men M2
xtreg  IndexWFCt child  jazouh uebstun  exper_yr tenure_yr   isei08a alter_j_kind  i.year pberwbt  pbazouh  if sexid==1, fe i(paarnr) vce(robust)
est store M2M


esttab  M1F M2F M1M  M2M /*
*/ using "X\Table 1 B.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


**Figure 1B Women
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year pberwbt pbazouh  if sexid==0, fe i(paarnr) vce(robust)
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*with adjustments in work investments
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child  jazouh uebstun exper_yr tenure_yr  isei08a alter_j_kind  i.year  pberwbt pbazouh  if sexid==0, fe i(paarnr) vce(robust)
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 

	
log close

********************************************
***                                      ***
***  // jack knife 			             ***
***                                      ***
********************************************

clear all
version 14.0
capture log close
set more off

global date "2022-02-22"
global data "#"
global do "#"
global results "#"
global log "#"

log using "X\WFC_Jackknife sector.log", replace

use "X\WFC_long_selsample.dta"



****Sector************

tab WZN, mis


*Table 1B1 Women Appendix B
*Without Sector 1: Manufacturing, Electricity, Water supply
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 &  WZN>1, fe i(paarnr) vce(robust)
est store M1FJN1
*Without Sector 2: Wholesale, retail trade, transport
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 &  (WZN==1 | WZN==3 | WZN==4 ), fe i(paarnr) vce(robust)
est store M1FJN2
*Without Sector 3: Financial and insurance activities, economic services
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 &  (WZN==1 | WZN==2 | WZN==4 ), fe i(paarnr) vce(robust)
est store M1FJN3
*Without Sector 4:Social, private and public services
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 & (WZN==1 | WZN==2 | WZN==3 ), fe i(paarnr) vce(robust)
est store M1FJN4

esttab  M1FJN1  M1FJN2  M1FJN3  M1FJN4 /*
*/ using "X\Jackknife Sector Women.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*Table 1B2 Men Appendix B
*Without Sector 1: Manufacturing, Electricity, Water supply
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 & WZN>1, fe i(paarnr) vce(robust)
est store M1MJN1
*Without Sector 2: Wholesale, retail trade, transport
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 &  (WZN==1 | WZN==3 | WZN==4 ), fe i(paarnr) vce(robust)
est store M1MJN2
*Without Sector 3: Financial and insurance activities, economic services
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 &  (WZN==1 | WZN==2 | WZN==4 ), fe i(paarnr) vce(robust)
est store M1MJN3
*Without Sector 4:Social, private and public services
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 & (WZN==1 | WZN==2 | WZN==3 ), fe i(paarnr) vce(robust) 
est store M1MJN4

esttab  M1MJN1  M1MJN2  M1MJN3  M1MJN4 /*
*/ using "X\Jackknife Sector Men.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*Figure 1B Women Appendix B
*Without Sector 1: Manufacturing, Electricity, Water supply
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year  if sexid==0 & WZN>1, fe i(paarnr) vce(robust)
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*Without Sector 2: Wholesale, retail trade, transport
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year  if sexid==0 & (WZN==1 | WZN==3 | WZN==4 ), fe i(paarnr) vce(robust)
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*Without Sector 3: Financial and insurance activities, economic services
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year  if sexid==0 & (WZN==1 | WZN==2 | WZN==4 ), fe i(paarnr) vce(robust)
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*Without Sector 4: Social, private and public services
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year  if sexid==0 &  (WZN==1 | WZN==2 | WZN==3 ), fe i(paarnr) vce(robust)
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 


**Table 3B1 Women: M1-M4 Appendix B
*Without Sector 1: Manufacturing, Electricity, Water supply
xtreg  IndexWFCt O_heim O_flex  if sexid==0 & WZN>1 ,  fe i(paarnr) vce(robust)
est store O1w1
xtreg  IndexWFCt O_heim  O_flex jaheiman jaflexazn  if sexid==0 & WZN>1 ,  fe i(paarnr) vce(robust)
est store O2w1
xtreg  IndexWFCt O_heim  O_flex  jaheiman jaflexazn i.year if sexid==0 &  WZN>1 ,  fe i(paarnr) vce(robust)
est store O3w1
xtreg  IndexWFCt O_heim  O_flex  jaheiman jaflexazn  i.year child alter_j_kind jazouh uebst exper_yr tenure_yr isei08a  if sexid==0 & WZN>1 ,  fe i(paarnr) vce(robust)
est store O4w1

esttab O1w1 O2w1 O3w1 O4w1 /*
*/ using "X\Result Org Women Without Sec1.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

*Without Sector 2: Wholesale, retail trade, transport
xtreg  IndexWFCt O_heim O_flex  if sexid==0 & (WZN==1 | WZN==3 | WZN==4 ) , fe i(paarnr) vce(robust) 
est store O1w2
xtreg  IndexWFCt O_heim  O_flex jaheiman jaflexazn  if sexid==0 & (WZN==1 | WZN==3 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O2w2
xtreg  IndexWFCt  O_heim  O_flex jaheiman jaflexazn i.year if sexid==0 & (WZN==1 | WZN==3 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O3w2
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn  i.year child alter_j_kind jazouh uebst exper_yr tenure_yr isei08a  if sexid==0 & (WZN==1 | WZN==3 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O4w2

esttab O1w2 O2w2 O3w2 O4w2 /*
*/ using "X\Result Org Women Without Sec2.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*Without Sector 3: Financial and insurance activities, economic services
xtreg  IndexWFCt O_heim O_flex  if sexid==0 & (WZN==1 | WZN==2 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O1w3
xtreg  IndexWFCt   O_heim  O_flex jaheiman jaflexazn  if sexid==0 & (WZN==1 | WZN==2 | WZN==4 ) , fe i(paarnr) vce(robust) 
est store O2w3
xtreg  IndexWFCt  O_heim O_flex  jaheiman jaflexazn i.year if sexid==0 & (WZN==1 | WZN==2 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O3w3
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  i.year child alter_j_kind jazouh uebst exper_yr tenure_yr isei08a  if sexid==0 & (WZN==1 | WZN==2 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O4w3

esttab O1w3 O2w3 O3w3 O4w3 /*
*/ using "X\Result Org Women Without Sec3.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*Without Sector 4: Social, private and public services
xtreg  IndexWFCt O_heim O_flex  if sexid==0 & (WZN==1 | WZN==2 | WZN==3 ) , fe i(paarnr) vce(robust)
est store O1w4
xtreg  IndexWFCt  O_heim O_flex  jaheiman jaflexazn  if sexid==0 & (WZN==1 | WZN==2 | WZN==3 ) , fe i(paarnr) vce(robust)
est store O2w4
xtreg  IndexWFCt  O_heim O_flex  jaheiman jaflexazn i.year if sexid==0 & (WZN==1 | WZN==2 | WZN==3 ) , fe i(paarnr) vce(robust)
est store O3w4
xtreg  IndexWFCt O_heim  O_flex jaheiman jaflexazn  i.year child alter_j_kind jazouh uebst exper_yr tenure_yr isei08a if sexid==0 & (WZN==1 | WZN==2 | WZN==3 ) , fe i(paarnr) vce(robust)
est store O4w4


esttab O1w4 O2w4 O3w4 O4w4 /*
*/ using "X\Result Org Women Without Sec4.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

 
**Table 3B2 Men: M1-M4 Appendix B
*Without Sector 1: Manufacturing, Electricity, Water supply
xtreg  IndexWFCt O_heim O_flex  if sexid==1 & WZN>1 ,  fe i(paarnr) vce(robust)
est store O1m1
xtreg  IndexWFCt O_heim  O_flex jaheiman jaflexazn  if sexid==1 & WZN>1 ,  fe i(paarnr) vce(robust)
est store O2m1
xtreg  IndexWFCt O_heim  O_flex  jaheiman jaflexazn i.year if sexid==1 &  WZN>1 ,  fe i(paarnr) vce(robust)
est store O3m1
xtreg  IndexWFCt O_heim  O_flex  jaheiman jaflexazn  i.year child alter_j_kind jazouh uebst exper_yr tenure_yr isei08a  if sexid==1 & WZN>1 ,  fe i(paarnr) vce(robust)
est store O4m1

esttab O1m1 O2m1 O3m1 O4m1 /*
*/ using "X\Result Org Men Without Sec1.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

*Without Sector 2: Wholesale, retail trade, transport
xtreg  IndexWFCt O_heim O_flex if sexid==1 & (WZN==1 | WZN==3 | WZN==4 ) , fe i(paarnr) vce(robust) 
est store O1m2
xtreg  IndexWFCt O_heim  O_flex  jaheiman jaflexazn  if sexid==1 & (WZN==1 | WZN==3 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O2m2
xtreg  IndexWFCt O_heim  O_flex jaheiman jaflexazn i.year if sexid==1 & (WZN==1 | WZN==3 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O3m2
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn  i.year child alter_j_kind jazouh uebst exper_yr tenure_yr isei08a  if sexid==1 & (WZN==1 | WZN==3 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O4m2

esttab O1m2 O2m2 O3m2 O4m2 /*
*/ using "X\Result Org Men Without Sec2.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*Without Sector 3: Financial and insurance activities, economic services
xtreg  IndexWFCt O_heim O_flex if sexid==1 & (WZN==1 | WZN==2 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O1m3
xtreg  IndexWFCt  O_heim  O_flex jaheiman jaflexazn  if sexid==1 & (WZN==1 | WZN==2 | WZN==4 ) , fe i(paarnr) vce(robust) 
est store O2m3
xtreg  IndexWFCt  O_heim O_flex  jaheiman jaflexazn i.year if sexid==1 & (WZN==1 | WZN==2 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O3m3
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  i.year child alter_j_kind jazouh uebst exper_yr tenure_yr isei08a  if sexid==1 & (WZN==1 | WZN==2 | WZN==4 ) , fe i(paarnr) vce(robust)
est store O4m3

esttab O1m3 O2m3 O3m3 O4m3 /*
*/ using "X\Result Org Men Without Sec3.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*Without Sector 4: Social, private and public services
xtreg  IndexWFCt O_heim O_flex if sexid==1 & (WZN==1 | WZN==2 | WZN==3 ) , fe i(paarnr) vce(robust)
est store O1m4
xtreg  IndexWFCt  O_heim  O_flex jaheiman jaflexazn  if sexid==1 & (WZN==1 | WZN==2 | WZN==3 ) , fe i(paarnr) vce(robust)
est store O2w4
xtreg  IndexWFCt  O_heim O_flex  jaheiman jaflexazn i.year if sexid==1 & (WZN==1 | WZN==2 | WZN==3 ) , fe i(paarnr) vce(robust)
est store O3m4
xtreg  IndexWFCt O_heim  O_flex  jaheiman jaflexazn  i.year child alter_j_kind jazouh uebst exper_yr tenure_yr isei08a if sexid==1 & (WZN==1 | WZN==2 | WZN==3 ) , fe i(paarnr) vce(robust)
est store O4m4


esttab O1m4 O2m4 O3m4 O4m4 /*
*/ using "X\Result Org Men Without Sec4.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)






****Jackknife Occupation*************

tab isco08_1sta,  mis

*Occupation 1: Managers, Occupation 2: Professionals, Occupation 3: Technicians and associate professionals; 
* Occupation 4: Clerical support workers, Occupation 5: Service and sales workers, 
* Occupation 6: Skilled agricultural, forestry and  fishery workers; Occupation 7: Craft and related trades workers, 
*Occupation 8: Plant and machine operators, and assemblers, Occupation 9: Elementary occupations


*Women Table 1C1 Appendix C
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 & isco08_1sta~=1, fe i(paarnr) vce(robust)
est store M1FJNO1
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 &  isco08_1sta~=2, fe i(paarnr) vce(robust) 
est store M1FJNO2
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 & isco08_1sta~=3, fe i(paarnr) vce(robust)
est store M1FJNO3
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 &  isco08_1sta~=4 , fe i(paarnr) vce(robust) 
est store M1FJNO4
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 &  isco08_1sta~=5 , fe i(paarnr) vce(robust)
est store M1FJNO5
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 &  isco08_1sta~=6 , fe i(paarnr) vce(robust)
est store M1FJNO6
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 &  isco08_1sta~=7 , fe i(paarnr) vce(robust)
est store M1FJNO7
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 &  isco08_1sta~=8 , fe i(paarnr) vce(robust)
est store M1FJNO8
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==0 &  isco08_1sta~=9 , fe i(paarnr) vce(robust)
est store M1FJNO9


esttab  M1FJNO1  M1FJNO2  M1FJNO3  M1FJNO4 M1FJNO5 M1FJNO6 M1FJNO7 M1FJNO8 M1FJNO9 /*
*/ using "X\Result jack knife occup female.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*Menn Table 1C1 Appendix C
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 & isco08_1sta~=1, fe i(paarnr) vce(robust) 
est store M1MJNO1
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 &  isco08_1sta~=2, fe i(paarnr) vce(robust) 
est store M1MJNO2
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 & isco08_1sta~=3, fe i(paarnr) vce(robust)
est store M1MJNO3
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 &  isco08_1sta~=4 , fe i(paarnr) vce(robust) 
est store M1MJNO4
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 &  isco08_1sta~=5 , fe i(paarnr) vce(robust) 
est store M1MJNO5
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 &  isco08_1sta~=6 , fe i(paarnr) vce(robust)
est store M1MJNO6
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 &  isco08_1sta~=7 , fe i(paarnr) vce(robust) 
est store M1MJNO7
xtreg IndexWFCt child alter_j_kind  i.year  if sexid==1 &  isco08_1sta~=8 , fe i(paarnr) vce(robust)
est store M1MJNO8
xtreg  IndexWFCt child alter_j_kind  i.year  if sexid==1 &  isco08_1sta~=9 , fe i(paarnr) vce(robust)
est store M1MJNO9


esttab  M1MJNO1  M1MJNO2  M1MJNO3  M1MJNO4 M1MJNO5 M1MJNO6 M1MJNO7 M1MJNO8 M1MJNO9 /*
*/ using "X\Result jack knife occup male.rtf", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)




**Figure 1C: Jack Knife Occupation Women
*without Occupation 1
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0 & isco08_1sta~=1, fe i(paarnr) vce(robust)
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*without Occupation 2
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0 & isco08_1sta~=2  , fe i(paarnr) vce(robust)
est store M4FJN2
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*without Occupation 3
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0 & isco08_1sta~=3  , fe i(paarnr) vce(robust)
est store M4FJN3
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*without Occupation 4
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0 & isco08_1sta~=4  , fe i(paarnr) vce(robust) 
est store M4FJN4
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*without Occupation 5
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0 & isco08_1sta~=5  , fe i(paarnr) vce(robust) 
est store M4FJN4
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*without Occupation 6
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0 & isco08_1sta~=6 , fe i(paarnr) vce(robust)
est store M4FJN4
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*without Occupation 7
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0 & isco08_1sta~=7 , fe i(paarnr) vce(robust)
est store M4FJN4
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*without Occupation 8
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0 & isco08_1sta~=8 , fe i(paarnr) vce(robust)
est store M4FJN4
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 
*without Occupation 9
xtreg  IndexWFCt i.jaheiman##i.child i.jaflexazn##i.child alter_j_kind  i.year    if sexid==0 & isco08_1sta~=9 , fe i(paarnr) vce(robust) 
est store M4FJN4
margins jaflexazn, at(child=(0(1)1)) noestimcheck
mplotoffset, level (90) ylabel(, angle(horizontal)) graphregion(color(white)) title("Predictive margins of flexitime with 90%CIs")  offset(0.02) ///
xlabel(, labsize(small)) ///
xtitle("Parenthood (0=no, 1=yes)") ///
plot( , label("No use flexitime" "Use of flexitime")) 



***Table 3C1 Women Appendix C
*without Occupation 1
xtreg  IndexWFCt O_heim O_flex if sexid==0 &  isco08_1sta~=1, fe i(paarnr) vce(robust) 
est store O1w1
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  if sexid==0 &    isco08_1sta~=1, fe i(paarnr) vce(robust) 
est store O2w1
xtreg  IndexWFCt O_heim O_flex   jaheiman jaflexazn i.year  if sexid==0 &    isco08_1sta~=1, fe i(paarnr) vce(robust)
est store O3w1 
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==0 &    isco08_1sta~=1, fe i(paarnr) vce(robust)
est store O4w1

esttab O1w1 O2w1 O3w1 O4w1  /*
*/ using "X\Result Org Women Without Occ1", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*without Occupation 2
xtreg  IndexWFCt O_heim O_flex  if sexid==0 &    isco08_1sta~=2, fe i(paarnr) vce(robust) 
est store O1w2
xtreg  IndexWFCt O_heim  O_flex jaheiman jaflexazn  if sexid==0 &    isco08_1sta~=2, fe i(paarnr) vce(robust) 
est store O2w2
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn i.year  if sexid==0 &    isco08_1sta~=2, fe i(paarnr) vce(robust)
est store O3w2
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==0 &    isco08_1sta~=2, fe i(paarnr) vce(robust) 
est store O4w2

esttab O1w2 O2w2 O3w2 O4w2  /*
*/ using "X\Result Org Women Without Occ2", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)



*without Occupation 3
xtreg  IndexWFCt O_heim O_flex  if sexid==0 &    isco08_1sta~=3, fe i(paarnr) vce(robust) 
est store O1w3
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  if sexid==0 &    isco08_1sta~=3, fe i(paarnr) vce(robust) 
est store O2w3
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn i.year  if sexid==0 &    isco08_1sta~=3, fe i(paarnr) vce(robust)
est store O3w3 
xtreg  IndexWFCt O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==0 &    isco08_1sta~=3, fe i(paarnr) vce(robust) 
est store O4w3

esttab O1w3 O2w3 O3w3 O4w3  /*
*/ using "X\Result Org Women Without Occ3", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*without Occupation 4
xtreg  IndexWFCt O_heim O_flex if sexid==0 & isco08_1sta~=4, fe i(paarnr) vce(robust) 
est store O1w4
xtreg  IndexWFCt O_heim O_flex jaheiman jaflexazn  if sexid==0 &    isco08_1sta~=4, fe i(paarnr) vce(robust) 
est store O2w4
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn i.year  if sexid==0 &    isco08_1sta~=4, fe i(paarnr) vce(robust)
est store O3w4 
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==0 &    isco08_1sta~=4, fe i(paarnr) vce(robust)
est store O4w4

esttab O1w4 O2w4 O3w4 O4w4  /*
*/ using "X\Result Org Women Without Occ4", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

*without Occupation 5
xtreg  IndexWFCt O_heim O_flex  if sexid==0 &    isco08_1sta~=5, fe i(paarnr) vce(robust)
est store O1w5
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  if sexid==0 &    isco08_1sta~=5, fe i(paarnr) vce(robust)
est store O2w5
xtreg  IndexWFCt  O_heim O_flex  jaheiman jaflexazn i.year  if sexid==0 &    isco08_1sta~=5, fe i(paarnr) vce(robust)
est store O3w5
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==0 &    isco08_1sta~=5, fe i(paarnr) vce(robust)
est store O4w5

esttab O1w5 O2w5 O3w5 O4w5  /*
*/ using "X\Result Org Women Without Occ5", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*without Occupation 6
xtreg  IndexWFCt O_heim O_flex if sexid==0 & isco08_1sta~=6, fe i(paarnr) vce(robust)
est store O1w6
xtreg  IndexWFCt  O_heim O_flex  jaheiman jaflexazn  if sexid==0 &  isco08_1sta~=6, fe i(paarnr) vce(robust)
est store O2w6
xtreg  IndexWFCt  O_heim  O_flex  jaheiman jaflexazn i.year  if sexid==0 &  isco08_1sta~=6, fe i(paarnr) vce(robust)
est store O3w6 
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==0 &    isco08_1sta~=6, fe i(paarnr) vce(robust)
est store O4w6

esttab O1w6 O2w6 O3w6 O4w6  /*
*/ using "X\Result Org Women Without Occ6", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

*without Occupation 7
xtreg  IndexWFCt  O_heim O_flex if sexid==0 &    isco08_1sta~=7, fe i(paarnr) vce(robust)
est store O1w7
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  if sexid==0 &    isco08_1sta~=7, fe i(paarnr) vce(robust)
est store O2w7
xtreg  IndexWFCt  O_heim  O_flex jaheiman jaflexazn i.year  if sexid==0 &    isco08_1sta~=7, fe i(paarnr) vce(robust)
est store O3w7 
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==0 &    isco08_1sta~=7, fe i(paarnr) vce(robust)
est store O4w7

esttab O1w7 O2w7 O3w7 O4w7  /*
*/ using "X\Result Org Women Without Occ7", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

*without Occupation 8
xtreg  IndexWFCt O_heim O_flex if sexid==0 &  isco08_1sta~=8, fe i(paarnr) vce(robust)
est store O1w8
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn  if sexid==0 &    isco08_1sta~=8, fe i(paarnr) vce(robust)
est store O2w8
xtreg  IndexWFCt   O_heim  O_flex jaheiman jaflexazn i.year  if sexid==0 &    isco08_1sta~=8, fe i(paarnr) vce(robust)
est store O3w8 
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==0 &    isco08_1sta~=8, fe i(paarnr) vce(robust)
est store O4w8

esttab O1w8 O2w8 O3w8 O4w8  /*
*/ using "X\Result Org Women Without Occ8", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

*without Occupation 9
xtreg  IndexWFCt O_heim O_flex if sexid==0 &    isco08_1sta~=9, fe i(paarnr) vce(robust)
est store O1w9
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  if sexid==0 &    isco08_1sta~=9, fe i(paarnr) vce(robust)
est store O2w9
xtreg  IndexWFCt  O_heim  O_flex jaheiman jaflexazn i.year  if sexid==0 &    isco08_1sta~=9, fe i(paarnr) vce(robust)
est store O3w9 
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==0 &    isco08_1sta~=9, fe i(paarnr) vce(robust)
est store O4w9

esttab O1w9 O2w9 O3w9 O4w9  /*
*/ using "X\Result Org Women Without Occ9", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)





***Table 3C2 Men Appendix C
*without Occupation 1
xtreg  IndexWFCt O_heim O_flex  if sexid==1 &  isco08_1sta~=1, fe i(paarnr) vce(robust)
est store O1mw1
xtreg  IndexWFCt  O_heim  O_flex jaheiman jaflexazn  if sexid==1 &    isco08_1sta~=1, fe i(paarnr) vce(robust) 
est store O2mw1
xtreg  IndexWFCt   O_heim O_flex jaheiman jaflexazn i.year  if sexid==1 &    isco08_1sta~=1, fe i(paarnr) vce(robust)
est store O3mw1 
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==1 &    isco08_1sta~=1, fe i(paarnr) vce(robust)
est store O4mw1

esttab O1mw1 O2mw1 O3mw1 O4mw1  /*
*/ using "X\Result Org Men Without Occ1", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*without Occupation 2
xtreg  IndexWFCt O_heim O_flex  if sexid==1 &    isco08_1sta~=2, fe i(paarnr) vce(robust) 
est store O1mw2
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn  if sexid==1 &    isco08_1sta~=2, fe i(paarnr) vce(robust) 
est store O2mw2
xtreg  IndexWFCt  O_heim  O_flex jaheiman jaflexazn i.year  if sexid==1 &    isco08_1sta~=2, fe i(paarnr) vce(robust)
est store O3mw2
xtreg  IndexWFCt O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==1 &    isco08_1sta~=2, fe i(paarnr) vce(robust)
est store O4mw2

esttab O1mw2 O2mw2 O3mw2 O4mw2  /*
*/ using "X\Result Org Men Without Occ2", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)



*without Occupation 3
xtreg  IndexWFCt O_heim O_flex if sexid==1 &    isco08_1sta~=3, fe i(paarnr) vce(robust) 
est store O1mw3
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  if sexid==1 &    isco08_1sta~=3, fe i(paarnr) vce(robust)
est store O2mw3
xtreg  IndexWFCt O_heim  O_flex  jaheiman jaflexazn i.year  if sexid==1 &    isco08_1sta~=3, fe i(paarnr) vce(robust)
est store O3mw3 
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==1 &    isco08_1sta~=3, fe i(paarnr) vce(robust)
est store O4mw3

esttab O1mw3 O2mw3 O3mw3 O4mw3  /*
*/ using "X\Result Org Men Without Occ3", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*without Occupation 4
xtreg  IndexWFCt O_heim O_flex if sexid==1 & isco08_1sta~=4, fe i(paarnr) vce(robust)
est store O1mw4
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  if sexid==1 &    isco08_1sta~=4, fe i(paarnr) vce(robust)
est store O2mw4
xtreg  IndexWFCt   O_heim  O_flex jaheiman jaflexazn i.year  if sexid==1 &    isco08_1sta~=4, fe i(paarnr) vce(robust)
est store O3mw4 
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==1 &    isco08_1sta~=4, fe i(paarnr) vce(robust) 
est store O4mw4

esttab O1mw4 O2mw4 O3mw4 O4mw4  /*
*/ using "X\Result Org Men Without Occ4", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

*without Occupation 5
xtreg  IndexWFCt O_heim O_flex if sexid==1 &    isco08_1sta~=5, fe i(paarnr) vce(robust)
est store O1mw5
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  if sexid==1 &    isco08_1sta~=5, fe i(paarnr) vce(robust)
est store O2mw5
xtreg  IndexWFCt  O_heim  O_flex jaheiman jaflexazn i.year  if sexid==1 &    isco08_1sta~=5, fe i(paarnr) vce(robust)
est store O3mw5
xtreg  IndexWFCt O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==1 &    isco08_1sta~=5, fe i(paarnr) vce(robust) 
est store O4mw5

esttab O1mw5 O2mw5 O3mw5 O4mw5  /*
*/ using "X\Result Org Men Without Occ5", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)


*without Occupation 6
xtreg  IndexWFCt O_heim O_flex if sexid==1 & isco08_1sta~=6, fe i(paarnr) vce(robust)
est store O1mw6
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  if sexid==1 &  isco08_1sta~=6, fe i(paarnr) vce(robust) 
est store O2mw6
xtreg  IndexWFCt  O_heim O_flex  jaheiman jaflexazn i.year  if sexid==1 &  isco08_1sta~=6, fe i(paarnr) vce(robust)
est store O3mw6 
xtreg  IndexWFCt O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==1 &    isco08_1sta~=6, fe i(paarnr) vce(robust)
est store O4mw6

esttab O1mw6 O2mw6 O3mw6 O4mw6  /*
*/ using "X\Result Org Men Without Occ6", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

*without Occupation 7
xtreg  IndexWFCt O_heim O_flex if sexid==1 &    isco08_1sta~=7, fe i(paarnr) vce(robust)
est store O1mw7
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn  if sexid==1 &    isco08_1sta~=7, fe i(paarnr) vce(robust)
est store O2mw7
xtreg  IndexWFCt  O_heim  O_flex jaheiman jaflexazn i.year  if sexid==1 &    isco08_1sta~=7, fe i(paarnr) vce(robust)
est store O3mw7 
xtreg  IndexWFCt O_heim O_flex  jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==1 &    isco08_1sta~=7, fe i(paarnr) vce(robust)
est store O4mw7

esttab O1mw7 O2mw7 O3mw7 O4mw7  /*
*/ using "X\Result Org Men Without Occ7", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

*without Occupation 8
xtreg  IndexWFCt O_heim O_flex if sexid==1 &  isco08_1sta~=8, fe i(paarnr) vce(robust) 
est store O1mw8
xtreg  IndexWFCt  O_heim O_flex  jaheiman jaflexazn  if sexid==1 &    isco08_1sta~=8, fe i(paarnr) vce(robust)
est store O2mw8
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn i.year  if sexid==1 &    isco08_1sta~=8, fe i(paarnr) vce(robust)
est store O3mw8 
xtreg  IndexWFCt O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==1 &    isco08_1sta~=8, fe i(paarnr) vce(robust)
est store O4mw8

esttab O1mw8 O2mw8 O3mw8 O4mw8  /*
*/ using "X\Result Org Men Without Occ8", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

*without Occupation 9
xtreg  IndexWFCt O_heim O_flex  if sexid==1 &    isco08_1sta~=9, fe i(paarnr) vce(robust)
est store O1mw9
xtreg  IndexWFCt  O_heim  O_flex jaheiman jaflexazn  if sexid==1 &    isco08_1sta~=9, fe i(paarnr) vce(robust)
est store O2mw9
xtreg  IndexWFCt  O_heim O_flex  jaheiman jaflexazn i.year  if sexid==1 &    isco08_1sta~=9, fe i(paarnr) vce(robust)
est store O3mw9 
xtreg  IndexWFCt  O_heim O_flex jaheiman jaflexazn i.year child alter_j_kind  jazouh uebst  exper_yr tenure_yr isei08a  if sexid==1 &    isco08_1sta~=9, fe i(paarnr) vce(robust)
est store O4mw9

esttab O1mw9 O2mw9 O3mw9 O4mw9  /*
*/ using "X\Result Org Men Without Occ9", /*
*/ nogaps nolines /*
*/ star (+ 0.10 * 0.05 ** 0.01 *** 0.001) replace b (%10.3f) /*
*/ se scalar (N N_g sigma_u sigma_e rho)

log close
